document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  
  menuToggle.addEventListener('click', () => {
    navLinks.classList.toggle('active');
    menuToggle.classList.toggle('active');
  });

  // Style buttons functionality
  const styleButtons = document.querySelectorAll('.controls button');
  const titlePreview = document.querySelector('.title-preview');

  const styles = {
    elegant: {
      fontFamily: 'Georgia, serif',
      letterSpacing: '2px',
      fontWeight: '300'
    },
    bold: {
      fontFamily: 'system-ui, sans-serif',
      letterSpacing: '-1px',
      fontWeight: '800'
    },
    playful: {
      fontFamily: 'Comic Sans MS, cursive',
      letterSpacing: '1px',
      fontWeight: '400'
    },
    minimal: {
      fontFamily: 'Arial, sans-serif',
      letterSpacing: '0',
      fontWeight: '400'
    }
  };

  styleButtons.forEach(button => {
    button.addEventListener('click', () => {
      const style = styles[button.dataset.style];
      Object.assign(titlePreview.style, style);
      
      // Remove active class from all buttons
      styleButtons.forEach(btn => btn.classList.remove('active'));
      // Add active class to clicked button
      button.classList.add('active');
    });
  });

  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      target.scrollIntoView({
        behavior: 'smooth'
      });
    });
  });

  // Animation on scroll
  const observerOptions = {
    threshold: 0.1
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.classList.add('visible');
      }
    });
  }, observerOptions);

  document.querySelectorAll('section').forEach(section => {
    observer.observe(section);
  });
});
